pysingular: A basic Python interface to Singular
================================================

Description
-----------

A basic interface to call Singular from python

This python module is meant to be used in Singulars Jupyter interface.

License
-------

GPL version 2 or later


Upstream Contact
----------------

-  https://github.com/sebasguts/SingularPython
